@@ -458,13 +458,11 @@ applyCRCheCluster() {
   echo "[INFO] Creating Custom Resource"
   CRs=$(yq -r '.metadata.annotations["alm-examples"]' "${CSV_FILE}")
   CR=$(echo "$CRs" | yq -r ".[0]")
+  CR=$(echo "$CR" | yq -r ".spec.devWorkspace.enable = ${DEV_WORKSPACE_ENABLE:-false}")
   if [ "${platform}" == "kubernetes" ]
   then
     CR=$(echo "$CR" | yq -r ".spec.k8s.ingressDomain = \"$(minikube ip).nip.io\"")
   fi
-  if [ "${platform}" == "openshift" ] && [ "${OAUTH}" == "false" ]; then
-    CR=$(echo "$CR" | yq -r ".spec.auth.openShiftoAuth = false")
-  fi
 
   echo "$CR" | kubectl apply -n "${namespace}" --validate=false -f -
 }
@@ -475,7 +473,7 @@ waitCheServerDeploy() {
     echo "[ERROR] Please specify first argument: 'namespace'"
     exit 1
   fi
-  
+
   echo "[INFO] Waiting for Che server to be deployed"
   set +e -x
 
