@@ -20,6 +20,7 @@ package v1
 
 import (
 	chev1alpha1 "github.com/che-incubator/kubernetes-image-puller-operator/pkg/apis/che/v1alpha1"
+	"github.com/eclipse-che/che-operator/pkg/apis/org/v2alpha1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/labels"
@@ -116,6 +117,7 @@ type CheClusterSpecServer struct {
 	// In that case, a new namespace will be created for each user or workspace.
 	// +optional
 	WorkspaceNamespaceDefault string `json:"workspaceNamespaceDefault,omitempty"`
+	// Deprecated. The value of this flag is ignored.
 	// Defines that a user is allowed to specify a Kubernetes namespace, or an OpenShift project, which differs from the default.
 	// It's NOT RECOMMENDED to set to `true` without OpenShift OAuth configured. The OpenShift infrastructure also uses this property.
 	// +optional
@@ -161,9 +163,13 @@ type CheClusterSpecServer struct {
 	// In cores. (500m = .5 cores). Default to 100m.
 	// +optional
 	DashboardCpuRequest string `json:"dashboardCpuRequest,omitempty"`
-	// Public URL of the devfile registry, that serves sample, ready-to-use devfiles.
-	// Set this ONLY when a use of an external devfile registry is needed. See the `externalDevfileRegistry` field.
-	// By default, this will be automatically calculated by the Operator.
+	// Dashboard ingress custom settings.
+	// +optional
+	DashboardIngress IngressCustomSettings `json:"dashboardIngress,omitempty"`
+	// Dashboard route custom settings.
+	// +optional
+	DashboardRoute RouteCustomSettings `json:"dashboardRoute,omitempty"`
+	// Deprecated in favor of `externalDevfileRegistries` fields.
 	// +optional
 	DevfileRegistryUrl string `json:"devfileRegistryUrl,omitempty"`
 	// Overrides the container image used in the devfile registry deployment.
@@ -195,10 +201,16 @@ type CheClusterSpecServer struct {
 	// +optional
 	DevfileRegistryRoute RouteCustomSettings `json:"devfileRegistryRoute,omitempty"`
 	// Instructs the Operator on whether to deploy a dedicated devfile registry server.
-	// By default, a dedicated devfile registry server is started. When `externalDevfileRegistry` is `true`, no such dedicated server
-	// will be started by the Operator and you will have to manually set the `devfileRegistryUrl` field
+	// By default, a dedicated devfile registry server is started. When `externalDevfileRegistry` is `true`,
+	// no such dedicated server will be started by the Operator and configure at least one
+	// devfile registry with `externalDevfileRegistries` field.
 	// +optional
 	ExternalDevfileRegistry bool `json:"externalDevfileRegistry"`
+	// External devfile registries, that serves sample, ready-to-use devfiles.
+	// Configure this in addition to a dedicated devfile registry (when `externalDevfileRegistry` is `false`)
+	// or instead of it (when `externalDevfileRegistry` is `true`)
+	// +optional
+	ExternalDevfileRegistries []ExternalDevfileRegistries `json:"externalDevfileRegistries,omitempty"`
 	// Public URL of the plugin registry that serves sample ready-to-use devfiles.
 	// Set this ONLY when a use of an external devfile registry is needed.
 	// See the `externalPluginRegistry` field. By default, this will be automatically calculated by the Operator.
@@ -452,6 +464,9 @@ type IngressCustomSettings struct {
 	// Comma separated list of labels that can be used to organize and categorize objects by scoping and selecting.
 	// +optional
 	Labels string `json:"labels,omitempty"`
+	// Unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
+	// +optional
+	Annotations map[string]string `json:"annotations,omitempty"`
 }
 
 // Route custom settings, can be extended in the future
@@ -464,6 +479,9 @@ type RouteCustomSettings struct {
 	// The generated host name will follow this pattern: `<route-name>-<route-namespace>.<domain>`.
 	// +optional
 	Domain string `json:"domain,omitempty"`
+	// Unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
+	// +optional
+	Annotations map[string]string `json:"annotations,omitempty"`
 }
 
 // ResourceRequirements describes the compute resource requirements.
@@ -585,6 +603,14 @@ type CheClusterSpecDevWorkspace struct {
 	ControllerImage string `json:"controllerImage,omitempty"`
 }
 
+// +k8s:openapi-gen=true
+// Settings for a configuration of the external devfile registries.
+type ExternalDevfileRegistries struct {
+	// Public URL of the devfile registry.
+	// +optional
+	Url string `json:"url,omitempty"`
+}
+
 // CheClusterStatus defines the observed state of Che installation
 type CheClusterStatus struct {
 	// OpenShift OAuth secret in `openshift-config` namespace that contains user credentials for HTPasswd identity provider.
@@ -658,6 +684,10 @@ type CheClusterStatus struct {
 	// +operator-sdk:gen-csv:customresourcedefinitions.statusDescriptors.displayName="Help link"
 	// +operator-sdk:gen-csv:customresourcedefinitions.statusDescriptors.x-descriptors="urn:alm:descriptor:org.w3:link"
 	HelpLink string `json:"helpLink,omitempty"`
+
+	// The status of the Devworkspace subsystem
+	// +optional
+	DevworkspaceStatus v2alpha1.CheClusterStatus `json:"devworkspaceStatus,omitempty"`
 }
 
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
@@ -666,6 +696,7 @@ type CheClusterStatus struct {
 // +k8s:openapi-gen=true
 // +kubebuilder:subresource:status
 // +operator-sdk:gen-csv:customresourcedefinitions.displayName="Eclipse Che Cluster"
+// +kubebuilder:storageversion
 type CheCluster struct {
 	metav1.TypeMeta   `json:",inline"`
 	metav1.ObjectMeta `json:"metadata,omitempty"`
