@@ -26,7 +26,7 @@ func TestDefaultFromEnv(t *testing.T) {
 	cheVersionTest := os.Getenv("CHE_VERSION")
 
 	cheServerImageTest := os.Getenv(util.GetArchitectureDependentEnv("RELATED_IMAGE_che_server"))
-
+	dashboardImageTest := os.Getenv(util.GetArchitectureDependentEnv("RELATED_IMAGE_dashboard"))
 	pluginRegistryImageTest := os.Getenv(util.GetArchitectureDependentEnv("RELATED_IMAGE_plugin_registry"))
 	devfileRegistryImageTest := os.Getenv(util.GetArchitectureDependentEnv("RELATED_IMAGE_devfile_registry"))
 	pvcJobsImageTest := os.Getenv(util.GetArchitectureDependentEnv("RELATED_IMAGE_pvc_jobs"))
@@ -50,6 +50,10 @@ func TestDefaultFromEnv(t *testing.T) {
 		t.Errorf("Expected %s but was %s", cheServerImageTest, DefaultCheServerImage(cheCluster))
 	}
 
+	if DefaultDashboardImage(cheCluster) != dashboardImageTest {
+		t.Errorf("Expected %s but was %s", dashboardImageTest, DefaultDashboardImage(cheCluster))
+	}
+
 	if DefaultPluginRegistryImage(cheCluster) != pluginRegistryImageTest {
 		t.Errorf("Expected %s but was %s", pluginRegistryImageTest, DefaultPluginRegistryImage(cheCluster))
 	}
@@ -85,9 +89,9 @@ func TestDefaultFromEnv(t *testing.T) {
 
 func TestCorrectImageName(t *testing.T) {
 	testCases := map[string]string{
-		"registry.redhat.io/codeready-workspaces/crw-2-rhel8-operator:latest":  "crw-2-rhel8-operator:latest",
+		"docker.io/eclipse/che-operator:latest": "che-operator:latest",
 		"eclipse/che-operator:7.1.0":            "che-operator:7.1.0",
-		"registry.redhat.io/codeready-workspaces/crw-2-rhel8-operator:2.8":  "crw-2-rhel8-operator:2.8",
+		"che-operator:7.2.0":                    "che-operator:7.2.0",
 	}
 	for k, v := range testCases {
 		t.Run(k, func(*testing.T) {
